@@ -437,6 +437,7 @@ xb_builder_source_get_istream(XbBuilderSource *self, GCancellable *cancellable,
 {
 	XbBuilderSourcePrivate *priv = GET_PRIVATE(self);
 	g_autofree gchar *basename = NULL;
+	g_autoptr(GInputStream) istream = NULL;
 	GFile *file;
 
 	g_return_val_if_fail(XB_IS_BUILDER_SOURCE(self), NULL);
@@ -446,8 +447,8 @@ xb_builder_source_get_istream(XbBuilderSource *self, GCancellable *cancellable,
 		return g_object_ref(priv->istream);
 
 	/* convert the file to a GFileInputStream */
-	priv->istream = G_INPUT_STREAM(g_file_read(priv->file, cancellable, error));
-	if (priv->istream == NULL)
+	istream = G_INPUT_STREAM(g_file_read(priv->file, cancellable, error));
+	if (istream == NULL)
 		return NULL;
 
 	/* run the content type handlers until we get application/xml */
@@ -458,7 +459,7 @@ xb_builder_source_get_istream(XbBuilderSource *self, GCancellable *cancellable,
 		XbBuilderSourceAdapter *item;
 		g_autofree gchar *content_type = NULL;
 		g_autoptr(GInputStream) istream_tmp = NULL;
-		g_autoptr(XbBuilderSourceCtx) ctx = xb_builder_source_ctx_new(file, priv->istream);
+		g_autoptr(XbBuilderSourceCtx) ctx = xb_builder_source_ctx_new(file, istream);
 
 		/* get the content type of the stream */
 		xb_builder_source_ctx_set_filename(ctx, basename);
@@ -467,6 +468,10 @@ xb_builder_source_get_istream(XbBuilderSource *self, GCancellable *cancellable,
 			return NULL;
 		if (g_strcmp0(content_type, "application/xml") == 0)
 			break;
+		/* Also accept the text/xml alias, just in case the user’s content-type database is slightly broken
+		 * (application/xml should normally be what’s used): */
+		if (g_strcmp0(content_type, "text/xml") == 0)
+			break;
 
 		/* convert the stream */
 		item = xb_builder_source_get_adapter_by_mime(self, content_type);
@@ -482,7 +487,7 @@ xb_builder_source_get_istream(XbBuilderSource *self, GCancellable *cancellable,
 		if (istream_tmp == NULL)
 			return NULL;
 		xb_builder_source_remove_last_extension(basename);
-		g_set_object(&priv->istream, istream_tmp);
+		g_set_object(&istream, istream_tmp);
 
 		/* the #GFile is only useful for the outermost input stream,
 		 * for example it points to the .tar.gz file, while inner input
@@ -493,7 +498,7 @@ xb_builder_source_get_istream(XbBuilderSource *self, GCancellable *cancellable,
 		if (item->is_simple)
 			break;
 	} while (TRUE);
-	return g_object_ref(priv->istream);
+	return g_steal_pointer(&istream);
 }
 
 GFile *
