@@ -200,6 +200,8 @@ xb_node_get_parent(XbNode *self)
 
 	g_return_val_if_fail(XB_IS_NODE(self), NULL);
 
+	if (priv->sn == NULL)
+		return NULL;
 	sn = xb_silo_get_parent_node(priv->silo, priv->sn);
 	if (sn == NULL)
 		return NULL;
@@ -224,6 +226,8 @@ xb_node_get_next(XbNode *self)
 
 	g_return_val_if_fail(XB_IS_NODE(self), NULL);
 
+	if (priv->sn == NULL)
+		return NULL;
 	sn = xb_silo_get_next_node(priv->silo, priv->sn);
 	if (sn == NULL)
 		return NULL;
@@ -248,6 +252,8 @@ xb_node_get_child(XbNode *self)
 
 	g_return_val_if_fail(XB_IS_NODE(self), NULL);
 
+	if (priv->sn == NULL)
+		return NULL;
 	sn = xb_silo_get_child_node(priv->silo, priv->sn);
 	if (sn == NULL)
 		return NULL;
@@ -301,7 +307,7 @@ xb_node_child_iter_init(XbNodeChildIter *iter, XbNode *self)
 	g_return_if_fail(XB_IS_NODE(self));
 
 	ri->node = self;
-	ri->position = xb_silo_get_child_node(priv->silo, priv->sn);
+	ri->position = priv->sn != NULL ? xb_silo_get_child_node(priv->silo, priv->sn) : NULL;
 	ri->first_iter = TRUE;
 }
 
@@ -422,6 +428,8 @@ xb_node_get_text(XbNode *self)
 {
 	XbNodePrivate *priv = GET_PRIVATE(self);
 	g_return_val_if_fail(XB_IS_NODE(self), NULL);
+	if (priv->sn == NULL)
+		return NULL;
 	return xb_silo_get_node_text(priv->silo, priv->sn);
 }
 
@@ -443,8 +451,9 @@ xb_node_get_text_as_uint(XbNode *self)
 
 	g_return_val_if_fail(XB_IS_NODE(self), G_MAXUINT64);
 
+	if (priv->sn == NULL)
+		return G_MAXUINT64;
 	tmp = xb_silo_get_node_text(priv->silo, priv->sn);
-	;
 	if (tmp == NULL)
 		return G_MAXUINT64;
 	if (g_str_has_prefix(tmp, "0x"))
@@ -467,6 +476,8 @@ xb_node_get_tail(XbNode *self)
 {
 	XbNodePrivate *priv = GET_PRIVATE(self);
 	g_return_val_if_fail(XB_IS_NODE(self), NULL);
+	if (priv->sn == NULL)
+		return NULL;
 	return xb_silo_get_node_tail(priv->silo, priv->sn);
 }
 
@@ -476,7 +487,7 @@ xb_node_get_tail(XbNode *self)
  *
  * Gets the element name for a specific node.
  *
- * Returns: a string, or %NULL for unset
+ * Returns: a string, or %NULL for the root node
  *
  * Since: 0.1.0
  **/
@@ -485,6 +496,8 @@ xb_node_get_element(XbNode *self)
 {
 	XbNodePrivate *priv = GET_PRIVATE(self);
 	g_return_val_if_fail(XB_IS_NODE(self), NULL);
+	if (priv->sn == NULL)
+		return NULL;
 	return xb_silo_get_node_element(priv->silo, priv->sn);
 }
 
@@ -508,6 +521,8 @@ xb_node_get_attr(XbNode *self, const gchar *name)
 	g_return_val_if_fail(XB_IS_NODE(self), NULL);
 	g_return_val_if_fail(name != NULL, NULL);
 
+	if (priv->sn == NULL)
+		return NULL;
 	a = xb_silo_get_node_attr_by_str(priv->silo, priv->sn, name);
 	if (a == NULL)
 		return NULL;
@@ -563,7 +578,7 @@ xb_node_attr_iter_init(XbNodeAttrIter *iter, XbNode *self)
 	g_return_if_fail(XB_IS_NODE(self));
 
 	ri->node = self;
-	ri->position = xb_silo_node_get_attr_count(priv->sn);
+	ri->position = priv->sn != NULL ? xb_silo_node_get_attr_count(priv->sn) : 0;
 }
 
 /**
@@ -632,6 +647,8 @@ xb_node_get_depth(XbNode *self)
 {
 	XbNodePrivate *priv = GET_PRIVATE(self);
 	g_return_val_if_fail(XB_IS_NODE(self), 0);
+	if (priv->sn == NULL)
+		return 0;
 	return xb_silo_get_node_depth(priv->silo, priv->sn);
 }
 
