@@ -921,7 +921,7 @@ xb_builder_fixup_ignore_node_cb(XbBuilderFixup *self,
 {
 	if (g_strcmp0(xb_builder_node_get_element(bn), "component") == 0) {
 		g_autoptr(XbBuilderNode) id = xb_builder_node_get_child(bn, "id", NULL);
-		if (g_strcmp0(xb_builder_node_get_text(id), "gimp.desktop") == 0)
+		if (id != NULL && g_strcmp0(xb_builder_node_get_text(id), "gimp.desktop") == 0)
 			xb_builder_node_add_flag(bn, XB_BUILDER_NODE_FLAG_IGNORE);
 	} else {
 		g_debug("ignoring %s", xb_builder_node_get_element(bn));
@@ -1206,9 +1206,9 @@ xb_xpath_parent_subnode_func(void)
 
 	/* import from XML */
 	silo = xb_silo_new_from_xml(xml, &error);
-	xb_silo_set_enable_node_cache(silo, TRUE);
 	g_assert_no_error(error);
 	g_assert_nonnull(silo);
+	xb_silo_set_enable_node_cache(silo, TRUE);
 
 	/* get node */
 	n = xb_silo_query_first(silo, "components/component", &error);
